@@ -175,18 +175,18 @@ repo_resolve(JSContext       *context,
         return true;
     }
 
-    GjsAutoJSChar name;
-    if (!gjs_get_string_id(context, id, &name)) {
+    priv = priv_from_js(context, obj);
+    gjs_debug_jsprop(GJS_DEBUG_GREPO, "Resolve prop '%s' hook, obj %s, priv %p",
+                     gjs_debug_id(id).c_str(), gjs_debug_object(obj).c_str(), priv);
+
+    if (priv == NULL) {
+        /* we are the prototype, or have the wrong class */
         *resolved = false;
         return true;
     }
 
-    priv = priv_from_js(context, obj);
-    gjs_debug_jsprop(GJS_DEBUG_GREPO, "Resolve prop '%s' hook obj %p priv %p",
-                     name.get(), obj.get(), priv);
-
-    if (priv == NULL) {
-        /* we are the prototype, or have the wrong class */
+    GjsAutoJSChar name;
+    if (!gjs_get_string_id(context, id, &name)) {
         *resolved = false;
         return true;
     }
