@@ -516,6 +516,8 @@ gjs_context_constructed(GObject *object)
     g_mutex_unlock (&contexts_lock);
 
     setup_dump_heap();
+
+    g_object_weak_ref(object, gjs_object_context_dispose_notify, nullptr);
 }
 
 static void
@@ -1077,3 +1079,16 @@ gjs_context_get_profiler(GjsContext *self)
 {
     return self->profiler;
 }
+
+/**
+ * gjs_get_js_version:
+ *
+ * Returns the underlying version of the JS engine.
+ *
+ * Returns: a string
+ */
+const char *
+gjs_get_js_version(void)
+{
+    return JS_GetImplementationVersion();
+}
