@@ -22,12 +22,16 @@
 
 #include <config.h>
 
+#include "gjs/jsapi-class.h"
 #include "gjs/jsapi-util-args.h"
 #include "gjs/jsapi-wrapper.h"
 #include <cairo.h>
 #include "cairo-private.h"
 
-GJS_DEFINE_PROTO("CairoLinearGradient", cairo_linear_gradient, JSCLASS_BACKGROUND_FINALIZE)
+static JSObject *gjs_cairo_linear_gradient_get_proto(JSContext *);
+
+GJS_DEFINE_PROTO_WITH_PARENT("LinearGradient", cairo_linear_gradient,
+                             cairo_gradient, JSCLASS_BACKGROUND_FINALIZE)
 
 GJS_NATIVE_CONSTRUCTOR_DECLARE(cairo_linear_gradient)
 {
@@ -73,6 +77,8 @@ JSFunctionSpec gjs_cairo_linear_gradient_proto_funcs[] = {
     JS_FS_END
 };
 
+JSFunctionSpec gjs_cairo_linear_gradient_static_funcs[] = { JS_FS_END };
+
 JSObject *
 gjs_cairo_linear_gradient_from_pattern(JSContext       *context,
                                        cairo_pattern_t *pattern)
@@ -81,8 +87,11 @@ gjs_cairo_linear_gradient_from_pattern(JSContext       *context,
     g_return_val_if_fail(pattern != NULL, NULL);
     g_return_val_if_fail(cairo_pattern_get_type(pattern) == CAIRO_PATTERN_TYPE_LINEAR, NULL);
 
+    JS::RootedObject proto(context,
+                           gjs_cairo_linear_gradient_get_proto(context));
     JS::RootedObject object(context,
-        JS_NewObject(context, &gjs_cairo_linear_gradient_class));
+        JS_NewObjectWithGivenProto(context, &gjs_cairo_linear_gradient_class,
+                                   proto));
     if (!object) {
         gjs_throw(context, "failed to create linear gradient pattern");
         return NULL;
